vexmpp\.protocols package
=========================

Submodules
----------

vexmpp\.protocols\.disco module
-------------------------------

.. automodule:: vexmpp.protocols.disco
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.entity\_time module
--------------------------------------

.. automodule:: vexmpp.protocols.entity_time
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.file\_transfer module
----------------------------------------

.. automodule:: vexmpp.protocols.file_transfer
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.iqregister module
------------------------------------

.. automodule:: vexmpp.protocols.iqregister
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.iqroster module
----------------------------------

.. automodule:: vexmpp.protocols.iqroster
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.iqversion module
-----------------------------------

.. automodule:: vexmpp.protocols.iqversion
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.muc module
-----------------------------

.. automodule:: vexmpp.protocols.muc
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.presence module
----------------------------------

.. automodule:: vexmpp.protocols.presence
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.resourcebind module
--------------------------------------

.. automodule:: vexmpp.protocols.resourcebind
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.sasl module
------------------------------

.. automodule:: vexmpp.protocols.sasl
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.sessionbind module
-------------------------------------

.. automodule:: vexmpp.protocols.sessionbind
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.stream\_mgmt module
--------------------------------------

.. automodule:: vexmpp.protocols.stream_mgmt
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.vcard module
-------------------------------

.. automodule:: vexmpp.protocols.vcard
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.protocols\.xdata module
-------------------------------

.. automodule:: vexmpp.protocols.xdata
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vexmpp.protocols
    :members:
    :undoc-members:
    :show-inheritance:
